/* individual-properties.c generated by valac 0.16.0, the Vala compiler
 * generated from individual-properties.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <tp-test-contactlist.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks/folks-telepathy.h>
#include <telepathy-glib/telepathy-glib.h>
#include <gio/gio.h>


#define TYPE_INDIVIDUAL_PROPERTIES_TESTS (individual_properties_tests_get_type ())
#define INDIVIDUAL_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTests))
#define INDIVIDUAL_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsClass))
#define IS_INDIVIDUAL_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS))
#define IS_INDIVIDUAL_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INDIVIDUAL_PROPERTIES_TESTS))
#define INDIVIDUAL_PROPERTIES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsClass))

typedef struct _IndividualPropertiesTests IndividualPropertiesTests;
typedef struct _IndividualPropertiesTestsClass IndividualPropertiesTestsClass;
typedef struct _IndividualPropertiesTestsPrivate IndividualPropertiesTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _Block7Data Block7Data;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData;

struct _IndividualPropertiesTests {
	FolksTestCase parent_instance;
	IndividualPropertiesTestsPrivate * priv;
};

struct _IndividualPropertiesTestsClass {
	FolksTestCaseClass parent_class;
};

struct _IndividualPropertiesTestsPrivate {
	TpTestBackend* tp_backend;
	void* _account_handle;
	gint _test_timeout;
	GeeHashSet* _changes_pending;
};

struct _Block1Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	GMainLoop* main_loop;
};

struct _Block2Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	GMainLoop* main_loop;
	gboolean alias_notified;
};

struct _Block3Data {
	int _ref_count_;
	Block2Data * _data2_;
	gchar* new_alias;
};

struct _Block4Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	GMainLoop* main_loop;
	gboolean alias_notified;
};

struct _Block5Data {
	int _ref_count_;
	Block4Data * _data4_;
	gchar* new_alias;
};

struct _Block6Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	GMainLoop* main_loop;
};

struct _Block7Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	GDateTime* new_birthday;
	FolksEmailFieldDetails* new_email_fd;
	FolksPhoneFieldDetails* new_phone_fd;
	FolksUrlFieldDetails* new_url_fd;
	gchar* new_full_name;
	gpointer _async_data_;
};

struct _IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	IndividualPropertiesTests* self;
	GeeMultiMap* changes;
	Block7Data* _data7_;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_;
	GeeSet* removed;
	GTimeVal timeval;
	GTimeVal _tmp4_;
	GDateTime* _tmp5_;
	FolksEmailFieldDetails* _tmp6_;
	FolksEmailFieldDetails* _tmp7_;
	FolksPhoneFieldDetails* _tmp8_;
	FolksPhoneFieldDetails* _tmp9_;
	FolksUrlFieldDetails* _tmp10_;
	FolksUrlFieldDetails* _tmp11_;
	gchar* _tmp12_;
	GeeCollection* _tmp13_;
	GeeIterator* _tmp14_;
	GeeIterator* _i_it;
	GeeIterator* _tmp15_;
	gboolean _tmp16_;
	GeeIterator* _tmp17_;
	gpointer _tmp18_;
	FolksIndividual* i;
	FolksIndividual* _tmp19_;
	gboolean _tmp20_;
	FolksIndividual* _tmp21_;
	GDateTime* _tmp22_;
	GDateTime* _tmp23_;
	GDateTime* _tmp24_;
	FolksIndividual* _tmp25_;
	GDateTime* _tmp26_;
	GDateTime* _tmp27_;
	gboolean _tmp28_;
	gboolean _tmp29_;
	FolksIndividual* _tmp30_;
	GeeSet* _tmp31_;
	GeeSet* _tmp32_;
	FolksEmailFieldDetails* _tmp33_;
	gboolean _tmp34_;
	const gchar* _tmp35_;
	FolksIndividual* _tmp36_;
	const gchar* _tmp37_;
	const gchar* _tmp38_;
	FolksIndividual* _tmp39_;
	GeeSet* _tmp40_;
	GeeSet* _tmp41_;
	FolksPhoneFieldDetails* _tmp42_;
	gboolean _tmp43_;
	FolksIndividual* _tmp44_;
	GeeSet* _tmp45_;
	GeeSet* _tmp46_;
	FolksUrlFieldDetails* _tmp47_;
	gboolean _tmp48_;
	FolksIndividual* _tmp49_;
	FolksIndividual* _tmp50_;
	FolksIndividual* _tmp51_;
	FolksIndividual* _tmp52_;
	FolksIndividual* _tmp53_;
	FolksPersona* persona;
	FolksIndividual* _tmp54_;
	GeeSet* _tmp55_;
	GeeSet* _tmp56_;
	GeeIterator* _tmp57_;
	GeeIterator* _p_it;
	GeeIterator* _tmp58_;
	gboolean _tmp59_;
	GeeIterator* _tmp60_;
	gpointer _tmp61_;
	FolksPersona* p;
	FolksPersona* _tmp62_;
	FolksPersona* _tmp63_;
	FolksPersona* _tmp64_;
	GeeHashSet* _tmp65_;
	GeeHashSet* emails;
	GeeHashSet* _tmp66_;
	FolksEmailFieldDetails* _tmp67_;
	GeeHashSet* _tmp68_;
	GeeHashSet* phones;
	GeeHashSet* _tmp69_;
	FolksPhoneFieldDetails* _tmp70_;
	GeeHashSet* _tmp71_;
	GeeHashSet* urls;
	GeeHashSet* _tmp72_;
	FolksUrlFieldDetails* _tmp73_;
	gint uncaught_errors;
	FolksIndividual* _tmp74_;
	gboolean _tmp75_;
	gboolean _tmp76_;
	gint _tmp77_;
	FolksPersona* _tmp78_;
	GDateTime* _tmp79_;
	GError* e_birthday;
	FolksIndividual* _tmp80_;
	gboolean _tmp81_;
	gboolean _tmp82_;
	gint _tmp83_;
	FolksIndividual* _tmp84_;
	gboolean _tmp85_;
	gboolean _tmp86_;
	gint _tmp87_;
	FolksPersona* _tmp88_;
	GeeHashSet* _tmp89_;
	GError* e0;
	FolksIndividual* _tmp90_;
	gboolean _tmp91_;
	gboolean _tmp92_;
	gint _tmp93_;
	FolksIndividual* _tmp94_;
	gboolean _tmp95_;
	gboolean _tmp96_;
	gint _tmp97_;
	FolksPersona* _tmp98_;
	const gchar* _tmp99_;
	GError* e1;
	FolksIndividual* _tmp100_;
	gboolean _tmp101_;
	gboolean _tmp102_;
	gint _tmp103_;
	FolksIndividual* _tmp104_;
	gboolean _tmp105_;
	gboolean _tmp106_;
	gint _tmp107_;
	FolksPersona* _tmp108_;
	GeeHashSet* _tmp109_;
	GError* e2;
	FolksIndividual* _tmp110_;
	gboolean _tmp111_;
	gboolean _tmp112_;
	gint _tmp113_;
	FolksIndividual* _tmp114_;
	gboolean _tmp115_;
	gboolean _tmp116_;
	gint _tmp117_;
	FolksPersona* _tmp118_;
	GeeHashSet* _tmp119_;
	GError* e3;
	FolksIndividual* _tmp120_;
	gboolean _tmp121_;
	gboolean _tmp122_;
	gint _tmp123_;
	FolksIndividual* _tmp124_;
	gboolean _tmp125_;
	gboolean _tmp126_;
	gint _tmp127_;
	GeeSet* _tmp128_;
	gint _tmp129_;
	gint _tmp130_;
	GeeSet* _tmp131_;
	GeeIterator* _tmp132_;
	GeeIterator* _r_it;
	GeeIterator* _tmp133_;
	gboolean _tmp134_;
	GeeIterator* _tmp135_;
	gpointer _tmp136_;
	FolksIndividual* r;
	FolksIndividual* _tmp137_;
	GError * _inner_error_;
};


static gpointer individual_properties_tests_parent_class = NULL;

GType individual_properties_tests_get_type (void) G_GNUC_CONST;
#define INDIVIDUAL_PROPERTIES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsPrivate))
enum  {
	INDIVIDUAL_PROPERTIES_TESTS_DUMMY_PROPERTY
};
IndividualPropertiesTests* individual_properties_tests_new (void);
IndividualPropertiesTests* individual_properties_tests_construct (GType object_type);
void individual_properties_tests_test_individual_properties (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_alias_through_test_cm (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_contact_info (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method (gpointer self);
static void individual_properties_tests_real_set_up (FolksTestCase* base);
static void individual_properties_tests_real_tear_down (FolksTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda2_ (IndividualPropertiesTests* self, GeeMultiMap* changes);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda3_ (Block1Data* _data1_);
static gboolean ___lambda3__gsource_func (gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda4_ (Block2Data* _data2_, GeeMultiMap* changes);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void ____lambda5_ (Block3Data* _data3_, GObject* s, GParamSpec* p);
static void _____lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ___lambda4__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda6_ (Block2Data* _data2_);
static gboolean ___lambda6__gsource_func (gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void __lambda7_ (Block4Data* _data4_, GeeMultiMap* changes);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void ____lambda8_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda9_ (Block4Data* _data4_);
static gboolean ___lambda9__gsource_func (gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void __lambda10_ (IndividualPropertiesTests* self, GeeMultiMap* changes);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added (IndividualPropertiesTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_finish (IndividualPropertiesTests* self, GAsyncResult* _res_);
static void ___lambda10__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda16_ (Block6Data* _data6_);
static gboolean ___lambda16__gsource_func (gpointer self);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free (gpointer _data);
static gboolean _individual_properties_tests_change_contact_info_aggregator_individuals_added_co (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void ____lambda11_ (Block7Data* _data7_, GObject* s, GParamSpec* p);
static void _____lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda12_ (Block7Data* _data7_, GObject* s, GParamSpec* p);
static void _____lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda13_ (Block7Data* _data7_, GObject* s, GParamSpec* p);
static void _____lambda13__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda14_ (Block7Data* _data7_, GObject* s, GParamSpec* p);
static void _____lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda15_ (Block7Data* _data7_, GObject* s, GParamSpec* p);
static void _____lambda15__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void individual_properties_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _individual_properties_tests_test_individual_properties_folks_test_case_test_method (gpointer self) {
#line 40 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties (self);
#line 371 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method (gpointer self) {
#line 42 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (self);
#line 378 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method (gpointer self) {
#line 44 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_alias_through_test_cm (self);
#line 385 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method (gpointer self) {
#line 46 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_contact_info (self);
#line 392 "individual-properties.c"
}


IndividualPropertiesTests* individual_properties_tests_construct (GType object_type) {
	IndividualPropertiesTests * self = NULL;
	TpTestBackend* _tmp0_;
	const gchar* _tmp1_ = NULL;
#line 36 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) folks_test_case_construct (object_type, "IndividualProperties");
#line 38 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = tp_test_backend_new ();
#line 38 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->tp_backend);
#line 38 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->tp_backend = _tmp0_;
#line 40 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties", _individual_properties_tests_test_individual_properties_folks_test_case_test_method, self);
#line 42 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change alias through tp backend", _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method, self);
#line 44 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change alias through test cm", _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method, self);
#line 46 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change contact info", _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method, self);
#line 49 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = g_getenv ("FOLKS_TEST_VALGRIND");
#line 49 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp1_ != NULL) {
#line 50 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self->priv->_test_timeout = 10;
#line 422 "individual-properties.c"
	}
#line 34 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return self;
#line 426 "individual-properties.c"
}


IndividualPropertiesTests* individual_properties_tests_new (void) {
#line 34 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return individual_properties_tests_construct (TYPE_INDIVIDUAL_PROPERTIES_TESTS);
#line 433 "individual-properties.c"
}


static void individual_properties_tests_real_set_up (FolksTestCase* base) {
	IndividualPropertiesTests * self;
	TpTestBackend* _tmp0_;
	TpTestBackend* _tmp1_;
	void* _tmp2_ = NULL;
	GeeHashSet* _tmp3_;
#line 53 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) base;
#line 55 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = self->priv->tp_backend;
#line 55 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	tp_test_backend_set_up (_tmp0_);
#line 56 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = self->priv->tp_backend;
#line 56 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = tp_test_backend_add_account (_tmp1_, "protocol", "me@example.com", "cm", "account");
#line 56 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->_account_handle = _tmp2_;
#line 58 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 58 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 58 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = _tmp3_;
#line 461 "individual-properties.c"
}


static void individual_properties_tests_real_tear_down (FolksTestCase* base) {
	IndividualPropertiesTests * self;
	TpTestBackend* _tmp0_;
	void* _tmp1_;
	TpTestBackend* _tmp2_;
#line 61 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) base;
#line 63 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = self->priv->tp_backend;
#line 63 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = self->priv->_account_handle;
#line 63 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	tp_test_backend_remove_account (_tmp0_, _tmp1_);
#line 64 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = self->priv->tp_backend;
#line 64 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	tp_test_backend_tear_down (_tmp2_);
#line 482 "individual-properties.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data1_;
#line 491 "individual-properties.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 500 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data1_->self;
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block1Data, _data1_);
#line 510 "individual-properties.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 101 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 518 "individual-properties.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	for (i = 0; i < stack_length; i++) {
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			return TRUE;
#line 530 "individual-properties.c"
		}
	}
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return FALSE;
#line 535 "individual-properties.c"
}


static void __lambda2_ (IndividualPropertiesTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	GeeSet* _tmp170_;
	gint _tmp171_;
	gint _tmp172_;
#line 73 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 75 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 75 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 75 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 76 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 76 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 76 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 563 "individual-properties.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp4_ = added;
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp5_;
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 576 "individual-properties.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			gboolean _tmp12_;
			gboolean _tmp13_;
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp6_ = _i_it;
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp7_) {
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 594 "individual-properties.c"
			}
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = _i_it;
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp9_;
#line 80 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = i;
#line 80 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_tmp10_ != NULL);
#line 83 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 83 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 83 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = _tmp12_;
#line 83 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_tmp13_) {
#line 614 "individual-properties.c"
				FolksIndividual* _tmp14_;
				const gchar* _tmp15_;
				const gchar* _tmp16_;
				FolksIndividual* _tmp17_;
				const gchar* _tmp18_;
				const gchar* _tmp19_;
				FolksIndividual* _tmp20_;
				const gchar* _tmp21_;
				const gchar* _tmp22_;
				FolksIndividual* _tmp23_;
				FolksPresenceType _tmp24_;
				FolksPresenceType _tmp25_;
				FolksIndividual* _tmp26_;
				gboolean _tmp27_ = FALSE;
				FolksIndividual* _tmp28_;
				GeeSet* _tmp29_;
				GeeSet* _tmp30_;
				gint _tmp31_;
				gint _tmp32_;
				TpfPersona* tpf_persona;
				TpfPersona* _tmp44_;
				TpfPersona* _tmp45_;
				gchar** _tmp46_;
				gint _tmp46__length1;
				gchar** _tmp47_;
				gint _tmp47__length1;
				TpfPersona* _tmp48_;
				gchar** _tmp49_;
				gint _tmp49__length1;
				gchar** _tmp50_;
				gint _tmp50__length1;
				TpfPersona* _tmp51_;
				gchar** _tmp52_;
				gint _tmp52__length1;
				gchar** _tmp53_;
				gint _tmp53__length1;
				TpfPersona* _tmp54_;
				gboolean _tmp55_;
				gboolean _tmp56_;
				TpfPersona* _tmp57_;
				gchar** _tmp58_;
				gint _tmp58__length1;
				gchar** _tmp59_;
				gint _tmp59__length1;
				TpfPersona* _tmp60_;
				gchar** _tmp61_;
				gint _tmp61__length1;
				gchar** _tmp62_;
				gint _tmp62__length1;
				TpfPersona* _tmp63_;
				gchar** _tmp64_;
				gint _tmp64__length1;
				gchar** _tmp65_;
				gint _tmp65__length1;
				TpfPersona* _tmp66_;
				gchar** _tmp67_;
				gint _tmp67__length1;
				gchar** _tmp68_;
				gint _tmp68__length1;
				TpfPersona* _tmp69_;
				gchar** _tmp70_;
				gint _tmp70__length1;
				gchar** _tmp71_;
				gint _tmp71__length1;
				FolksIndividual* _tmp72_;
				const gchar* _tmp73_;
				const gchar* _tmp74_;
				FolksIndividual* _tmp75_;
				GeeSet* _tmp76_;
				GeeSet* _tmp77_;
				gint _tmp78_;
				gint _tmp79_;
#line 86 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp14_ = i;
#line 86 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp15_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp14_);
#line 86 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp16_ = _tmp15_;
#line 86 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (g_strcmp0 (_tmp16_, "me@example.com") == 0);
#line 87 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp17_ = i;
#line 87 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp18_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) _tmp17_);
#line 87 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp19_ = _tmp18_;
#line 87 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (g_strcmp0 (_tmp19_, "") == 0);
#line 88 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 88 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) _tmp20_);
#line 88 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 88 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (g_strcmp0 (_tmp22_, "available") == 0);
#line 89 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = i;
#line 89 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp24_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp23_);
#line 89 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp25_ = _tmp24_;
#line 89 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_tmp25_ == FOLKS_PRESENCE_TYPE_AVAILABLE);
#line 90 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp26_ = i;
#line 90 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp27_ = folks_presence_details_is_online (FOLKS_PRESENCE_DETAILS (_tmp26_));
#line 90 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_tmp27_ == TRUE);
#line 93 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp28_ = i;
#line 93 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp29_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp28_);
#line 93 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp30_ = _tmp29_;
#line 93 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 93 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp32_ = _tmp31_;
#line 93 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_tmp32_ == 0);
#line 96 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				tpf_persona = NULL;
#line 739 "individual-properties.c"
				{
					FolksIndividual* _tmp33_;
					GeeSet* _tmp34_;
					GeeSet* _tmp35_;
					GeeIterator* _tmp36_ = NULL;
					GeeIterator* _p_it;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp33_ = i;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp35_ = _tmp34_;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_p_it = _tmp36_;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					while (TRUE) {
#line 758 "individual-properties.c"
						GeeIterator* _tmp37_;
						gboolean _tmp38_ = FALSE;
						GeeIterator* _tmp39_;
						gpointer _tmp40_ = NULL;
						FolksPersona* p;
						FolksPersona* _tmp41_;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp37_ = _p_it;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp38_ = gee_iterator_next (_tmp37_);
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						if (!_tmp38_) {
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							break;
#line 773 "individual-properties.c"
						}
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp39_ = _p_it;
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp40_ = gee_iterator_get (_tmp39_);
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						p = (FolksPersona*) _tmp40_;
#line 99 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp41_ = p;
#line 99 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						if (TPF_IS_PERSONA (_tmp41_)) {
#line 785 "individual-properties.c"
							FolksPersona* _tmp42_;
							TpfPersona* _tmp43_;
#line 101 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp42_ = p;
#line 101 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp43_ = _g_object_ref0 (TPF_IS_PERSONA (_tmp42_) ? ((TpfPersona*) _tmp42_) : NULL);
#line 101 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (tpf_persona);
#line 101 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							tpf_persona = _tmp43_;
#line 102 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (p);
#line 102 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							break;
#line 800 "individual-properties.c"
						}
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_g_object_unref0 (p);
#line 804 "individual-properties.c"
					}
#line 97 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_p_it);
#line 808 "individual-properties.c"
				}
#line 105 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp44_ = tpf_persona;
#line 105 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_tmp44_ != NULL);
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp45_ = tpf_persona;
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp46_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp45_, &_tmp46__length1);
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp47_ = _tmp46_;
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp47__length1 = _tmp46__length1;
#line 106 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp47_, _tmp47__length1, "alias"));
#line 107 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp48_ = tpf_persona;
#line 107 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp49_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp48_, &_tmp49__length1);
#line 107 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp50_ = _tmp49_;
#line 107 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp50__length1 = _tmp49__length1;
#line 107 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp50_, _tmp50__length1, "is-favourite"));
#line 108 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp51_ = tpf_persona;
#line 108 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp52_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp51_, &_tmp52__length1);
#line 108 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp53_ = _tmp52_;
#line 108 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp53__length1 = _tmp52__length1;
#line 108 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp53_, _tmp53__length1, "groups"));
#line 110 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp54_ = tpf_persona;
#line 110 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp55_ = folks_persona_get_is_user ((FolksPersona*) _tmp54_);
#line 110 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp56_ = _tmp55_;
#line 110 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_tmp56_);
#line 111 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp57_ = tpf_persona;
#line 111 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp58_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp57_, &_tmp58__length1);
#line 111 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp59_ = _tmp58_;
#line 111 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp59__length1 = _tmp58__length1;
#line 111 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp59_, _tmp59__length1, "birthday"));
#line 112 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp60_ = tpf_persona;
#line 112 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp61_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp60_, &_tmp61__length1);
#line 112 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp62_ = _tmp61_;
#line 112 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp62__length1 = _tmp61__length1;
#line 112 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp62_, _tmp62__length1, "email-addresses"));
#line 114 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp63_ = tpf_persona;
#line 114 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp64_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp63_, &_tmp64__length1);
#line 114 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp65_ = _tmp64_;
#line 114 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp65__length1 = _tmp64__length1;
#line 114 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp65_, _tmp65__length1, "full-name"));
#line 115 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp66_ = tpf_persona;
#line 115 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp67_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp66_, &_tmp67__length1);
#line 115 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp68_ = _tmp67_;
#line 115 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp68__length1 = _tmp67__length1;
#line 115 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp68_, _tmp68__length1, "phone-numbers"));
#line 117 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp69_ = tpf_persona;
#line 117 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp70_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp69_, &_tmp70__length1);
#line 117 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp71_ = _tmp70_;
#line 117 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp71__length1 = _tmp70__length1;
#line 117 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_vala_string_array_contains (_tmp71_, _tmp71__length1, "urls"));
#line 120 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp72_ = i;
#line 120 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp73_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp72_);
#line 120 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp74_ = _tmp73_;
#line 120 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (g_strcmp0 (_tmp74_, "") == 0);
#line 121 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp75_ = i;
#line 121 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp76_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp75_);
#line 121 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp77_ = _tmp76_;
#line 121 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp78_ = gee_collection_get_size ((GeeCollection*) _tmp77_);
#line 121 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp79_ = _tmp78_;
#line 121 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_tmp79_ == 0);
#line 83 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (tpf_persona);
#line 924 "individual-properties.c"
			} else {
				FolksIndividual* _tmp80_;
				const gchar* _tmp81_;
				const gchar* _tmp82_;
#line 126 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp80_ = i;
#line 126 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp81_ = folks_individual_get_id (_tmp80_);
#line 126 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp82_ = _tmp81_;
#line 126 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (g_strcmp0 (_tmp82_, "0e46c5e74f61908f49550d241f2a1651892a1695") == 0) {
#line 937 "individual-properties.c"
					FolksIndividual* _tmp83_;
					const gchar* _tmp84_;
					const gchar* _tmp85_;
					FolksIndividual* _tmp86_;
					const gchar* _tmp87_;
					const gchar* _tmp88_;
					FolksIndividual* _tmp89_;
					const gchar* _tmp90_;
					const gchar* _tmp91_;
					FolksIndividual* _tmp92_;
					FolksPresenceType _tmp93_;
					FolksPresenceType _tmp94_;
					FolksIndividual* _tmp95_;
					gboolean _tmp96_ = FALSE;
					FolksIndividual* _tmp97_;
					GeeSet* _tmp98_;
					GeeSet* _tmp99_;
					gint _tmp100_;
					gint _tmp101_;
					FolksIndividual* _tmp102_;
					GeeSet* _tmp103_;
					GeeSet* _tmp104_;
					gboolean _tmp105_ = FALSE;
					FolksIndividual* _tmp106_;
					GeeSet* _tmp107_;
					GeeSet* _tmp108_;
					gboolean _tmp109_ = FALSE;
					TpfPersona* tpf_persona;
					TpfPersona* _tmp121_;
					TpfPersona* _tmp122_;
					gchar** _tmp123_;
					gint _tmp123__length1;
					gchar** _tmp124_;
					gint _tmp124__length1;
					TpfPersona* _tmp125_;
					gchar** _tmp126_;
					gint _tmp126__length1;
					gchar** _tmp127_;
					gint _tmp127__length1;
					TpfPersona* _tmp128_;
					gchar** _tmp129_;
					gint _tmp129__length1;
					gchar** _tmp130_;
					gint _tmp130__length1;
					TpfPersona* _tmp131_;
					gboolean _tmp132_;
					gboolean _tmp133_;
					TpfPersona* _tmp134_;
					gchar** _tmp135_;
					gint _tmp135__length1;
					gchar** _tmp136_;
					gint _tmp136__length1;
					TpfPersona* _tmp137_;
					gchar** _tmp138_;
					gint _tmp138__length1;
					gchar** _tmp139_;
					gint _tmp139__length1;
					TpfPersona* _tmp140_;
					gchar** _tmp141_;
					gint _tmp141__length1;
					gchar** _tmp142_;
					gint _tmp142__length1;
					TpfPersona* _tmp143_;
					gchar** _tmp144_;
					gint _tmp144__length1;
					gchar** _tmp145_;
					gint _tmp145__length1;
					TpfPersona* _tmp146_;
					gchar** _tmp147_;
					gint _tmp147__length1;
					gchar** _tmp148_;
					gint _tmp148__length1;
					FolksIndividual* _tmp149_;
					GeeSet* _tmp150_;
					GeeSet* _tmp151_;
					FolksPhoneFieldDetails* _tmp152_;
					FolksPhoneFieldDetails* _tmp153_;
					gboolean _tmp154_ = FALSE;
					FolksIndividual* _tmp155_;
					const gchar* _tmp156_;
					const gchar* _tmp157_;
					FolksIndividual* _tmp158_;
					GeeSet* _tmp159_;
					GeeSet* _tmp160_;
					FolksEmailFieldDetails* _tmp161_;
					FolksEmailFieldDetails* _tmp162_;
					gboolean _tmp163_ = FALSE;
					FolksIndividual* _tmp164_;
					GeeSet* _tmp165_;
					GeeSet* _tmp166_;
					FolksUrlFieldDetails* _tmp167_;
					FolksUrlFieldDetails* _tmp168_;
					gboolean _tmp169_ = FALSE;
#line 129 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp83_ = i;
#line 129 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp84_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp83_);
#line 129 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp85_ = _tmp84_;
#line 129 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (g_strcmp0 (_tmp85_, "Olivier") == 0);
#line 130 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp86_ = i;
#line 130 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp87_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) _tmp86_);
#line 130 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp88_ = _tmp87_;
#line 130 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (g_strcmp0 (_tmp88_, "") == 0);
#line 131 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp89_ = i;
#line 131 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp90_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) _tmp89_);
#line 131 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp91_ = _tmp90_;
#line 131 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (g_strcmp0 (_tmp91_, "away") == 0);
#line 132 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp92_ = i;
#line 132 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp93_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp92_);
#line 132 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp94_ = _tmp93_;
#line 132 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp94_ == FOLKS_PRESENCE_TYPE_AWAY);
#line 133 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp95_ = i;
#line 133 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp96_ = folks_presence_details_is_online (FOLKS_PRESENCE_DETAILS (_tmp95_));
#line 133 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp96_ == TRUE);
#line 136 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp97_ = i;
#line 136 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp98_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp97_);
#line 136 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp99_ = _tmp98_;
#line 136 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp100_ = gee_collection_get_size ((GeeCollection*) _tmp99_);
#line 136 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp101_ = _tmp100_;
#line 136 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp101_ == 2);
#line 137 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp102_ = i;
#line 137 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp103_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp102_);
#line 137 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp104_ = _tmp103_;
#line 137 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp105_ = gee_collection_contains ((GeeCollection*) _tmp104_, "Montreal");
#line 137 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp105_ == TRUE);
#line 138 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp106_ = i;
#line 138 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp107_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp106_);
#line 138 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp108_ = _tmp107_;
#line 138 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp109_ = gee_collection_contains ((GeeCollection*) _tmp108_, "Francophones");
#line 138 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp109_ == TRUE);
#line 141 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					tpf_persona = NULL;
#line 1103 "individual-properties.c"
					{
						FolksIndividual* _tmp110_;
						GeeSet* _tmp111_;
						GeeSet* _tmp112_;
						GeeIterator* _tmp113_ = NULL;
						GeeIterator* _p_it;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp110_ = i;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp111_ = folks_individual_get_personas (_tmp110_);
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp112_ = _tmp111_;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_tmp113_ = gee_iterable_iterator ((GeeIterable*) _tmp112_);
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_p_it = _tmp113_;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						while (TRUE) {
#line 1122 "individual-properties.c"
							GeeIterator* _tmp114_;
							gboolean _tmp115_ = FALSE;
							GeeIterator* _tmp116_;
							gpointer _tmp117_ = NULL;
							FolksPersona* p;
							FolksPersona* _tmp118_;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp114_ = _p_it;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp115_ = gee_iterator_next (_tmp114_);
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							if (!_tmp115_) {
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								break;
#line 1137 "individual-properties.c"
							}
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp116_ = _p_it;
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp117_ = gee_iterator_get (_tmp116_);
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							p = (FolksPersona*) _tmp117_;
#line 144 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_tmp118_ = p;
#line 144 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							if (TPF_IS_PERSONA (_tmp118_)) {
#line 1149 "individual-properties.c"
								FolksPersona* _tmp119_;
								TpfPersona* _tmp120_;
#line 146 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								_tmp119_ = p;
#line 146 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								_tmp120_ = _g_object_ref0 (TPF_IS_PERSONA (_tmp119_) ? ((TpfPersona*) _tmp119_) : NULL);
#line 146 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								_g_object_unref0 (tpf_persona);
#line 146 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								tpf_persona = _tmp120_;
#line 147 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								_g_object_unref0 (p);
#line 147 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
								break;
#line 1164 "individual-properties.c"
							}
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (p);
#line 1168 "individual-properties.c"
						}
#line 142 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						_g_object_unref0 (_p_it);
#line 1172 "individual-properties.c"
					}
#line 150 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp121_ = tpf_persona;
#line 150 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp121_ != NULL);
#line 151 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp122_ = tpf_persona;
#line 151 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp123_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp122_, &_tmp123__length1);
#line 151 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp124_ = _tmp123_;
#line 151 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp124__length1 = _tmp123__length1;
#line 151 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_vala_string_array_contains (_tmp124_, _tmp124__length1, "alias"));
#line 152 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp125_ = tpf_persona;
#line 152 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp126_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp125_, &_tmp126__length1);
#line 152 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp127_ = _tmp126_;
#line 152 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp127__length1 = _tmp126__length1;
#line 152 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_vala_string_array_contains (_tmp127_, _tmp127__length1, "is-favourite"));
#line 153 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp128_ = tpf_persona;
#line 153 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp129_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp128_, &_tmp129__length1);
#line 153 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp130_ = _tmp129_;
#line 153 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp130__length1 = _tmp129__length1;
#line 153 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_vala_string_array_contains (_tmp130_, _tmp130__length1, "groups"));
#line 155 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp131_ = tpf_persona;
#line 155 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp132_ = folks_persona_get_is_user ((FolksPersona*) _tmp131_);
#line 155 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp133_ = _tmp132_;
#line 155 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (!_tmp133_);
#line 156 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp134_ = tpf_persona;
#line 156 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp135_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp134_, &_tmp135__length1);
#line 156 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp136_ = _tmp135_;
#line 156 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp136__length1 = _tmp135__length1;
#line 156 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (!_vala_string_array_contains (_tmp136_, _tmp136__length1, "birthday"));
#line 157 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp137_ = tpf_persona;
#line 157 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp138_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp137_, &_tmp138__length1);
#line 157 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp139_ = _tmp138_;
#line 157 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp139__length1 = _tmp138__length1;
#line 157 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (!_vala_string_array_contains (_tmp139_, _tmp139__length1, "email-addresses"));
#line 159 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp140_ = tpf_persona;
#line 159 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp141_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp140_, &_tmp141__length1);
#line 159 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp142_ = _tmp141_;
#line 159 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp142__length1 = _tmp141__length1;
#line 159 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (!_vala_string_array_contains (_tmp142_, _tmp142__length1, "full-name"));
#line 160 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp143_ = tpf_persona;
#line 160 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp144_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp143_, &_tmp144__length1);
#line 160 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp145_ = _tmp144_;
#line 160 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp145__length1 = _tmp144__length1;
#line 160 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (!_vala_string_array_contains (_tmp145_, _tmp145__length1, "phone-numbers"));
#line 162 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp146_ = tpf_persona;
#line 162 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp147_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp146_, &_tmp147__length1);
#line 162 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp148_ = _tmp147_;
#line 162 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp148__length1 = _tmp147__length1;
#line 162 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (!_vala_string_array_contains (_tmp148_, _tmp148__length1, "urls"));
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp149_ = i;
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp150_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp149_);
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp151_ = _tmp150_;
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp152_ = folks_phone_field_details_new ("+15142345678", NULL);
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp153_ = _tmp152_;
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp154_ = gee_collection_contains ((GeeCollection*) _tmp151_, _tmp153_);
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp154_);
#line 165 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp153_);
#line 167 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp155_ = i;
#line 167 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp156_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp155_);
#line 167 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp157_ = _tmp156_;
#line 167 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (g_strcmp0 (_tmp157_, "Olivier Crete") == 0);
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp158_ = i;
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp159_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp158_);
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp160_ = _tmp159_;
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp161_ = folks_email_field_details_new ("olivier@example.com", NULL);
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp162_ = _tmp161_;
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp163_ = gee_collection_contains ((GeeCollection*) _tmp160_, _tmp162_);
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp163_);
#line 168 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp162_);
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp164_ = i;
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp165_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp164_);
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp166_ = _tmp165_;
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp167_ = folks_url_field_details_new ("ocrete.example.com", NULL);
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp168_ = _tmp167_;
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp169_ = gee_collection_contains ((GeeCollection*) _tmp166_, _tmp168_);
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_assert (_tmp169_);
#line 170 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp168_);
#line 126 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (tpf_persona);
#line 1324 "individual-properties.c"
				}
			}
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1329 "individual-properties.c"
		}
#line 78 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1333 "individual-properties.c"
	}
#line 174 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp170_ = removed;
#line 174 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp171_ = gee_collection_get_size ((GeeCollection*) _tmp170_);
#line 174 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp172_ = _tmp171_;
#line 174 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_tmp172_ == 1);
#line 1343 "individual-properties.c"
	{
		GeeSet* _tmp173_;
		GeeIterator* _tmp174_ = NULL;
		GeeIterator* _i_it;
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp173_ = removed;
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp174_ = gee_iterable_iterator ((GeeIterable*) _tmp173_);
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp174_;
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1356 "individual-properties.c"
			GeeIterator* _tmp175_;
			gboolean _tmp176_ = FALSE;
			GeeIterator* _tmp177_;
			gpointer _tmp178_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp179_;
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp175_ = _i_it;
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp176_ = gee_iterator_next (_tmp175_);
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp176_) {
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1371 "individual-properties.c"
			}
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp177_ = _i_it;
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp178_ = gee_iterator_get (_tmp177_);
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp178_;
#line 178 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp179_ = i;
#line 178 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_tmp179_ == NULL);
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1385 "individual-properties.c"
		}
#line 176 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1389 "individual-properties.c"
	}
#line 73 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 73 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 1395 "individual-properties.c"
}


static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 73 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	__lambda2_ (self, changes);
#line 1402 "individual-properties.c"
}


static gboolean __lambda3_ (Block1Data* _data1_) {
	IndividualPropertiesTests * self;
	gboolean result = FALSE;
#line 186 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data1_->self;
#line 188 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_quit (_data1_->main_loop);
#line 189 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	result = FALSE;
#line 189 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 1417 "individual-properties.c"
}


static gboolean ___lambda3__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda3_ (self);
#line 186 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 1426 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties (IndividualPropertiesTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* aggregator;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gint _tmp4_;
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data1_->_ref_count_ = 1;
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data1_->self = g_object_ref (self);
#line 69 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 69 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data1_->main_loop = _tmp0_;
#line 72 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_new ();
#line 72 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 73 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 73 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_object (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda2__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 181 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 181 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 186 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = self->priv->_test_timeout;
#line 186 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp4_, ___lambda3__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 192 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_run (_data1_->main_loop);
#line 195 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 195 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block1_data_unref (_data1_);
#line 67 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data1_ = NULL;
#line 1478 "individual-properties.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data2_;
#line 1487 "individual-properties.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1496 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data2_->self;
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_main_loop_unref0 (_data2_->main_loop);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block2Data, _data2_);
#line 1506 "individual-properties.c"
	}
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data3_;
#line 1516 "individual-properties.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1525 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data3_->_data2_->self;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data3_->new_alias);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		block2_data_unref (_data3_->_data2_);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data3_->_data2_ = NULL;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block3Data, _data3_);
#line 1537 "individual-properties.c"
	}
}


static void ____lambda5_ (Block3Data* _data3_, GObject* s, GParamSpec* p) {
	Block2Data* _data2_;
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	FolksIndividual* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_ = _data3_->_data2_;
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data2_->self;
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 229 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 229 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 229 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 231 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 231 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp2_);
#line 231 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 231 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data3_->new_alias;
#line 231 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 232 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data2_->alias_notified = TRUE;
#line 1578 "individual-properties.c"
	}
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 1582 "individual-properties.c"
}


static void _____lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda5_ (self, _sender, pspec);
#line 1589 "individual-properties.c"
}


static void __lambda4_ (Block2Data* _data2_, GeeMultiMap* changes) {
	IndividualPropertiesTests * self;
	Block3Data* _data3_;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	gchar* _tmp4_;
	GeeSet* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data2_->self;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data3_->_ref_count_ = 1;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data3_->_data2_ = block2_data_ref (_data2_);
#line 207 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 207 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 207 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 208 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 208 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 208 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 210 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = g_strdup ("New Alias");
#line 210 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data3_->new_alias = _tmp4_;
#line 1632 "individual-properties.c"
	{
		GeeCollection* _tmp5_;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _i_it;
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = added;
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp6_;
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1645 "individual-properties.c"
			GeeIterator* _tmp7_;
			gboolean _tmp8_ = FALSE;
			GeeIterator* _tmp9_;
			gpointer _tmp10_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp11_;
			FolksIndividual* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
			FolksIndividual* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
			const gchar* _tmp18_;
			FolksIndividual* _tmp19_;
			FolksPersona* persona;
			FolksPersona* _tmp30_;
			FolksPersona* _tmp31_;
			const gchar* _tmp32_;
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = _i_it;
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp8_) {
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1672 "individual-properties.c"
			}
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = _i_it;
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp10_;
#line 214 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 214 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_tmp11_ != NULL);
#line 218 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = i;
#line 218 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 218 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp14_ = _tmp13_;
#line 218 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (g_strcmp0 (_tmp14_, "0e46c5e74f61908f49550d241f2a1651892a1695") != 0) {
#line 220 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (i);
#line 220 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				continue;
#line 1696 "individual-properties.c"
			}
#line 224 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp15_ = i;
#line 224 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp16_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp15_);
#line 224 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp17_ = _tmp16_;
#line 224 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp18_ = _data3_->new_alias;
#line 224 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (g_strcmp0 (_tmp17_, _tmp18_) != 0);
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp19_ = i;
#line 226 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _tmp19_, "notify::alias", (GCallback) _____lambda5__g_object_notify, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 237 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			persona = NULL;
#line 1714 "individual-properties.c"
			{
				FolksIndividual* _tmp20_;
				GeeSet* _tmp21_;
				GeeSet* _tmp22_;
				GeeIterator* _tmp23_ = NULL;
				GeeIterator* _p_it;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_individual_get_personas (_tmp20_);
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_p_it = _tmp23_;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 1733 "individual-properties.c"
					GeeIterator* _tmp24_;
					gboolean _tmp25_ = FALSE;
					GeeIterator* _tmp26_;
					gpointer _tmp27_ = NULL;
					FolksPersona* p;
					FolksPersona* _tmp28_;
					FolksPersona* _tmp29_;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp24_ = _p_it;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp25_ = gee_iterator_next (_tmp24_);
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (!_tmp25_) {
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						break;
#line 1749 "individual-properties.c"
					}
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp26_ = _p_it;
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp27_ = gee_iterator_get (_tmp26_);
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					p = (FolksPersona*) _tmp27_;
#line 240 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp28_ = p;
#line 240 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp29_ = _g_object_ref0 (_tmp28_);
#line 240 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (persona);
#line 240 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					persona = _tmp29_;
#line 241 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (p);
#line 241 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					break;
#line 1769 "individual-properties.c"
				}
#line 238 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_p_it);
#line 1773 "individual-properties.c"
			}
#line 243 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp30_ = persona;
#line 243 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (TPF_IS_PERSONA (_tmp30_));
#line 248 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp31_ = persona;
#line 248 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp32_ = _data3_->new_alias;
#line 248 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			folks_alias_details_set_alias ((FolksAliasDetails*) TPF_PERSONA (_tmp31_), _tmp32_);
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (persona);
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1789 "individual-properties.c"
		}
#line 212 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1793 "individual-properties.c"
	}
#line 251 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp33_ = removed;
#line 251 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp34_ = gee_collection_get_size ((GeeCollection*) _tmp33_);
#line 251 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp35_ = _tmp34_;
#line 251 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_tmp35_ == 1);
#line 1803 "individual-properties.c"
	{
		GeeSet* _tmp36_;
		GeeIterator* _tmp37_ = NULL;
		GeeIterator* _i_it;
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp36_ = removed;
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp37_ = gee_iterable_iterator ((GeeIterable*) _tmp36_);
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp37_;
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1816 "individual-properties.c"
			GeeIterator* _tmp38_;
			gboolean _tmp39_ = FALSE;
			GeeIterator* _tmp40_;
			gpointer _tmp41_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp42_;
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp38_ = _i_it;
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp39_ = gee_iterator_next (_tmp38_);
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp39_) {
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1831 "individual-properties.c"
			}
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp40_ = _i_it;
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp41_ = gee_iterator_get (_tmp40_);
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp41_;
#line 255 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp42_ = i;
#line 255 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_tmp42_ == NULL);
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1845 "individual-properties.c"
		}
#line 253 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1849 "individual-properties.c"
	}
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block3_data_unref (_data3_);
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data3_ = NULL;
#line 1859 "individual-properties.c"
}


static void ___lambda4__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	__lambda4_ (self, changes);
#line 1866 "individual-properties.c"
}


static gboolean __lambda6_ (Block2Data* _data2_) {
	IndividualPropertiesTests * self;
	gboolean result = FALSE;
#line 263 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data2_->self;
#line 265 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_quit (_data2_->main_loop);
#line 266 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	result = FALSE;
#line 266 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 1881 "individual-properties.c"
}


static gboolean ___lambda6__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda6_ (self);
#line 263 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 1890 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (IndividualPropertiesTests* self) {
	Block2Data* _data2_;
	GMainLoop* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* aggregator;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gint _tmp4_;
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->_ref_count_ = 1;
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->self = g_object_ref (self);
#line 200 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 200 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->main_loop = _tmp0_;
#line 201 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->alias_notified = FALSE;
#line 204 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_new ();
#line 204 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 205 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_data (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda4__folks_individual_aggregator_individuals_changed_detailed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 258 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 258 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 263 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = self->priv->_test_timeout;
#line 263 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp4_, ___lambda6__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 269 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_run (_data2_->main_loop);
#line 271 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_data2_->alias_notified);
#line 274 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 274 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block2_data_unref (_data2_);
#line 198 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data2_ = NULL;
#line 1946 "individual-properties.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data4_;
#line 1955 "individual-properties.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1964 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data4_->self;
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_main_loop_unref0 (_data4_->main_loop);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block4Data, _data4_);
#line 1974 "individual-properties.c"
	}
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data5_;
#line 1984 "individual-properties.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 1993 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data5_->_data4_->self;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data5_->new_alias);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		block4_data_unref (_data5_->_data4_);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data5_->_data4_ = NULL;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block5Data, _data5_);
#line 2005 "individual-properties.c"
	}
}


static void ____lambda8_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	Block4Data* _data4_;
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	FolksIndividual* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_ = _data5_->_data4_;
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data4_->self;
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 308 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 308 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 308 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 310 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 310 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp2_);
#line 310 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 310 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_alias;
#line 310 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 311 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data4_->alias_notified = TRUE;
#line 2046 "individual-properties.c"
	}
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2050 "individual-properties.c"
}


static void _____lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda8_ (self, _sender, pspec);
#line 2057 "individual-properties.c"
}


static void __lambda7_ (Block4Data* _data4_, GeeMultiMap* changes) {
	IndividualPropertiesTests * self;
	Block5Data* _data5_;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	gchar* _tmp4_;
	GeeSet* _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data4_->self;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data5_ = g_slice_new0 (Block5Data);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data5_->_ref_count_ = 1;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data5_->_data4_ = block4_data_ref (_data4_);
#line 286 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 286 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 286 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 287 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 287 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 287 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 289 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = g_strdup ("New Alias");
#line 289 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data5_->new_alias = _tmp4_;
#line 2100 "individual-properties.c"
	{
		GeeCollection* _tmp5_;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _i_it;
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = added;
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp6_;
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 2113 "individual-properties.c"
			GeeIterator* _tmp7_;
			gboolean _tmp8_ = FALSE;
			GeeIterator* _tmp9_;
			gpointer _tmp10_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp11_;
			FolksIndividual* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
			FolksIndividual* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
			const gchar* _tmp18_;
			FolksIndividual* _tmp19_;
			FolksPersona* persona;
			FolksPersona* _tmp30_;
			FolksPersona* _tmp31_;
			TpContact* _tmp32_;
			TpContact* _tmp33_;
			guint _tmp34_;
			guint _tmp35_;
			TpHandle handle;
			TpTestBackend* _tmp36_;
			TpTestContactListConnection* _tmp37_;
			TpTestContactListConnection* _tmp38_;
			TpTestContactListManager* _tmp39_;
			TpTestContactListManager* _tmp40_;
			TpHandle _tmp41_;
			const gchar* _tmp42_;
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = _i_it;
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp8_) {
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2151 "individual-properties.c"
			}
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = _i_it;
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp10_;
#line 293 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 293 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_tmp11_ != NULL);
#line 297 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = i;
#line 297 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 297 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp14_ = _tmp13_;
#line 297 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (g_strcmp0 (_tmp14_, "0e46c5e74f61908f49550d241f2a1651892a1695") != 0) {
#line 299 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (i);
#line 299 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				continue;
#line 2175 "individual-properties.c"
			}
#line 303 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp15_ = i;
#line 303 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp16_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp15_);
#line 303 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp17_ = _tmp16_;
#line 303 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp18_ = _data5_->new_alias;
#line 303 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (g_strcmp0 (_tmp17_, _tmp18_) != 0);
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp19_ = i;
#line 305 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _tmp19_, "notify::alias", (GCallback) _____lambda8__g_object_notify, block5_data_ref (_data5_), (GClosureNotify) block5_data_unref, 0);
#line 316 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			persona = NULL;
#line 2193 "individual-properties.c"
			{
				FolksIndividual* _tmp20_;
				GeeSet* _tmp21_;
				GeeSet* _tmp22_;
				GeeIterator* _tmp23_ = NULL;
				GeeIterator* _p_it;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_individual_get_personas (_tmp20_);
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_p_it = _tmp23_;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 2212 "individual-properties.c"
					GeeIterator* _tmp24_;
					gboolean _tmp25_ = FALSE;
					GeeIterator* _tmp26_;
					gpointer _tmp27_ = NULL;
					FolksPersona* p;
					FolksPersona* _tmp28_;
					FolksPersona* _tmp29_;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp24_ = _p_it;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp25_ = gee_iterator_next (_tmp24_);
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (!_tmp25_) {
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						break;
#line 2228 "individual-properties.c"
					}
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp26_ = _p_it;
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp27_ = gee_iterator_get (_tmp26_);
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					p = (FolksPersona*) _tmp27_;
#line 319 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp28_ = p;
#line 319 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_tmp29_ = _g_object_ref0 (_tmp28_);
#line 319 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (persona);
#line 319 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					persona = _tmp29_;
#line 320 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (p);
#line 320 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					break;
#line 2248 "individual-properties.c"
				}
#line 317 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_p_it);
#line 2252 "individual-properties.c"
			}
#line 322 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp30_ = persona;
#line 322 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (TPF_IS_PERSONA (_tmp30_));
#line 327 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp31_ = persona;
#line 327 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp32_ = tpf_persona_get_contact (TPF_PERSONA (_tmp31_));
#line 327 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp33_ = _tmp32_;
#line 327 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp34_ = tp_contact_get_handle (_tmp33_);
#line 327 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp35_ = _tmp34_;
#line 327 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			handle = (TpHandle) _tmp35_;
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp36_ = self->priv->tp_backend;
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp37_ = tp_test_backend_get_connection (_tmp36_);
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp38_ = _tmp37_;
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp39_ = tp_test_contact_list_connection_get_manager (_tmp38_);
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp40_ = _tmp39_;
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp41_ = handle;
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp42_ = _data5_->new_alias;
#line 328 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			tp_test_contact_list_manager_set_alias (_tmp40_, _tmp41_, _tmp42_);
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (persona);
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 2290 "individual-properties.c"
		}
#line 291 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 2294 "individual-properties.c"
	}
#line 331 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp43_ = removed;
#line 331 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp44_ = gee_collection_get_size ((GeeCollection*) _tmp43_);
#line 331 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp45_ = _tmp44_;
#line 331 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_tmp45_ == 1);
#line 2304 "individual-properties.c"
	{
		GeeSet* _tmp46_;
		GeeIterator* _tmp47_ = NULL;
		GeeIterator* _i_it;
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp46_ = removed;
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp47_ = gee_iterable_iterator ((GeeIterable*) _tmp46_);
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp47_;
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 2317 "individual-properties.c"
			GeeIterator* _tmp48_;
			gboolean _tmp49_ = FALSE;
			GeeIterator* _tmp50_;
			gpointer _tmp51_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp52_;
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp48_ = _i_it;
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp49_ = gee_iterator_next (_tmp48_);
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp49_) {
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2332 "individual-properties.c"
			}
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp50_ = _i_it;
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp51_ = gee_iterator_get (_tmp50_);
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp51_;
#line 335 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_tmp52_ = i;
#line 335 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_tmp52_ == NULL);
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 2346 "individual-properties.c"
		}
#line 333 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 2350 "individual-properties.c"
	}
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block5_data_unref (_data5_);
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data5_ = NULL;
#line 2360 "individual-properties.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	__lambda7_ (self, changes);
#line 2367 "individual-properties.c"
}


static gboolean __lambda9_ (Block4Data* _data4_) {
	IndividualPropertiesTests * self;
	gboolean result = FALSE;
#line 343 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data4_->self;
#line 345 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_quit (_data4_->main_loop);
#line 346 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	result = FALSE;
#line 346 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2382 "individual-properties.c"
}


static gboolean ___lambda9__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda9_ (self);
#line 343 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2391 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_alias_through_test_cm (IndividualPropertiesTests* self) {
	Block4Data* _data4_;
	GMainLoop* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* aggregator;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gint _tmp4_;
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->_ref_count_ = 1;
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->self = g_object_ref (self);
#line 279 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 279 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->main_loop = _tmp0_;
#line 280 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->alias_notified = FALSE;
#line 283 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_new ();
#line 283 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 284 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_data (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed_detailed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 338 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 338 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 343 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = self->priv->_test_timeout;
#line 343 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp4_, ___lambda9__gsource_func, block4_data_ref (_data4_), block4_data_unref);
#line 349 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_run (_data4_->main_loop);
#line 351 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_data4_->alias_notified);
#line 354 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 354 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block4_data_unref (_data4_);
#line 277 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data4_ = NULL;
#line 2447 "individual-properties.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data6_;
#line 2456 "individual-properties.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 2465 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data6_->self;
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_main_loop_unref0 (_data6_->main_loop);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block6Data, _data6_);
#line 2475 "individual-properties.c"
	}
}


static void __lambda10_ (IndividualPropertiesTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
#line 368 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 370 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 370 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added (self, _tmp0_, NULL, NULL);
#line 2488 "individual-properties.c"
}


static void ___lambda10__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 368 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	__lambda10_ (self, changes);
#line 2495 "individual-properties.c"
}


static gboolean __lambda16_ (Block6Data* _data6_) {
	IndividualPropertiesTests * self;
	gboolean result = FALSE;
#line 378 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data6_->self;
#line 380 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 381 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	result = FALSE;
#line 381 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2510 "individual-properties.c"
}


static gboolean ___lambda16__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda16_ (self);
#line 378 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2519 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_contact_info (IndividualPropertiesTests* self) {
	Block6Data* _data6_;
	GMainLoop* _tmp0_;
	GeeHashSet* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* _tmp3_;
	GeeHashSet* _tmp4_;
	GeeHashSet* _tmp5_;
	FolksIndividualAggregator* _tmp6_;
	FolksIndividualAggregator* aggregator;
	FolksIndividualAggregator* _tmp7_;
	FolksIndividualAggregator* _tmp8_;
	gint _tmp9_;
	GeeHashSet* _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data6_->_ref_count_ = 1;
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data6_->self = g_object_ref (self);
#line 359 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 359 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data6_->main_loop = _tmp0_;
#line 360 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = self->priv->_changes_pending;
#line 360 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp1_, "birthday");
#line 361 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = self->priv->_changes_pending;
#line 361 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp2_, "email-addresses");
#line 362 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = self->priv->_changes_pending;
#line 362 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, "phone-numbers");
#line 363 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = self->priv->_changes_pending;
#line 363 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, "full-name");
#line 364 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = self->priv->_changes_pending;
#line 364 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, "urls");
#line 367 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = folks_individual_aggregator_new ();
#line 367 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp6_;
#line 368 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp7_ = aggregator;
#line 368 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_object (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda10__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 373 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp8_ = aggregator;
#line 373 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp8_, NULL, NULL);
#line 378 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp9_ = self->priv->_test_timeout;
#line 378 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp9_, ___lambda16__gsource_func, block6_data_ref (_data6_), block6_data_unref);
#line 384 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_main_loop_run (_data6_->main_loop);
#line 386 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp10_ = self->priv->_changes_pending;
#line 386 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp11_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp10_);
#line 386 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp12_ = _tmp11_;
#line 386 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_tmp12_ == 0);
#line 389 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 389 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block6_data_unref (_data6_);
#line 357 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data6_ = NULL;
#line 2607 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free (gpointer _data) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
	_data_ = _data;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->changes);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_slice_free (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData, _data_);
#line 2620 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added (IndividualPropertiesTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
	IndividualPropertiesTests* _tmp0_;
	GeeMultiMap* _tmp1_;
	GeeMultiMap* _tmp2_;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_ = g_slice_new0 (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _individual_properties_tests_change_contact_info_aggregator_individuals_added);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->self = _tmp0_;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = changes;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->changes = _tmp2_;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added_co (_data_);
#line 2647 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_finish (IndividualPropertiesTests* self, GAsyncResult* _res_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2655 "individual-properties.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _data7_;
#line 2664 "individual-properties.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 2673 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		self = _data7_->self;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data7_->new_full_name);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data7_->new_url_fd);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data7_->new_phone_fd);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data7_->new_email_fd);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_date_time_unref0 (_data7_->new_birthday);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block7Data, _data7_);
#line 2691 "individual-properties.c"
	}
}


static void ____lambda11_ (Block7Data* _data7_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	FolksIndividual* _tmp4_;
	GDateTime* _tmp5_;
	GDateTime* _tmp6_;
	gboolean _tmp8_;
	gboolean _tmp14_;
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data7_->self;
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 426 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 426 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 426 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = ind;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp4_);
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = _tmp5_;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_ != NULL) {
#line 2728 "individual-properties.c"
		GDateTime* _tmp7_;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = _data7_->new_birthday;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp3_ = _tmp7_ != NULL;
#line 2734 "individual-properties.c"
	} else {
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp3_ = FALSE;
#line 2738 "individual-properties.c"
	}
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp8_ = _tmp3_;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp8_) {
#line 2744 "individual-properties.c"
		FolksIndividual* _tmp9_;
		GDateTime* _tmp10_;
		GDateTime* _tmp11_;
		GDateTime* _tmp12_;
		gboolean _tmp13_ = FALSE;
#line 429 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp9_ = ind;
#line 429 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp10_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp9_);
#line 429 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp11_ = _tmp10_;
#line 429 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp12_ = _data7_->new_birthday;
#line 429 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp13_ = g_date_time_equal (_tmp11_, _tmp12_);
#line 429 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp2_ = _tmp13_;
#line 2762 "individual-properties.c"
	} else {
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp2_ = FALSE;
#line 2766 "individual-properties.c"
	}
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp14_ = _tmp2_;
#line 428 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp14_) {
#line 2772 "individual-properties.c"
		GeeHashSet* _tmp15_;
#line 431 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp15_ = self->priv->_changes_pending;
#line 431 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp15_, "birthday");
#line 2778 "individual-properties.c"
	}
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2782 "individual-properties.c"
}


static void _____lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda11_ (self, _sender, pspec);
#line 2789 "individual-properties.c"
}


static void ____lambda12_ (Block7Data* _data7_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	FolksIndividual* _tmp2_;
	GeeSet* _tmp3_;
	GeeSet* _tmp4_;
	FolksEmailFieldDetails* _tmp5_;
	gboolean _tmp6_ = FALSE;
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data7_->self;
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 438 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 438 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 438 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 440 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 440 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp2_);
#line 440 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 440 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data7_->new_email_fd;
#line 440 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 440 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2827 "individual-properties.c"
		GeeHashSet* _tmp7_;
#line 442 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 442 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "email-addresses");
#line 2833 "individual-properties.c"
	}
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2837 "individual-properties.c"
}


static void _____lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda12_ (self, _sender, pspec);
#line 2844 "individual-properties.c"
}


static void ____lambda13_ (Block7Data* _data7_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	FolksIndividual* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data7_->self;
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 449 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 449 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 449 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 451 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 451 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 451 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 451 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data7_->new_full_name;
#line 451 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 2879 "individual-properties.c"
		GeeHashSet* _tmp6_;
#line 452 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = self->priv->_changes_pending;
#line 452 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp6_, "full-name");
#line 2885 "individual-properties.c"
	}
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2889 "individual-properties.c"
}


static void _____lambda13__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda13_ (self, _sender, pspec);
#line 2896 "individual-properties.c"
}


static void ____lambda14_ (Block7Data* _data7_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	FolksIndividual* _tmp2_;
	GeeSet* _tmp3_;
	GeeSet* _tmp4_;
	FolksPhoneFieldDetails* _tmp5_;
	gboolean _tmp6_ = FALSE;
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data7_->self;
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 458 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 458 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 458 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 460 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 460 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp2_);
#line 460 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 460 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data7_->new_phone_fd;
#line 460 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 460 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2934 "individual-properties.c"
		GeeHashSet* _tmp7_;
#line 462 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 462 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "phone-numbers");
#line 2940 "individual-properties.c"
	}
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2944 "individual-properties.c"
}


static void _____lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda14_ (self, _sender, pspec);
#line 2951 "individual-properties.c"
}


static void ____lambda15_ (Block7Data* _data7_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* ind;
	FolksIndividual* _tmp2_;
	GeeSet* _tmp3_;
	GeeSet* _tmp4_;
	FolksUrlFieldDetails* _tmp5_;
	gboolean _tmp6_ = FALSE;
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = _data7_->self;
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 469 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 469 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 469 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 471 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 471 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp2_);
#line 471 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 471 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data7_->new_url_fd;
#line 471 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 471 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2989 "individual-properties.c"
		GeeHashSet* _tmp7_;
#line 473 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 473 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "urls");
#line 2995 "individual-properties.c"
	}
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2999 "individual-properties.c"
}


static void _____lambda15__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	____lambda15_ (self, _sender, pspec);
#line 3006 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_ = _user_data_;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_source_object_ = source_object;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_res_ = _res_;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added_co (_data_);
#line 3020 "individual-properties.c"
}


static gboolean _individual_properties_tests_change_contact_info_aggregator_individuals_added_co (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_) {
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	switch (_data_->_state_) {
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		case 0:
#line 3029 "individual-properties.c"
		goto _state_0;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		case 1:
#line 3033 "individual-properties.c"
		goto _state_1;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		case 2:
#line 3037 "individual-properties.c"
		goto _state_2;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		case 3:
#line 3041 "individual-properties.c"
		goto _state_3;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		case 4:
#line 3045 "individual-properties.c"
		goto _state_4;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		case 5:
#line 3049 "individual-properties.c"
		goto _state_5;
		default:
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_assert_not_reached ();
#line 3054 "individual-properties.c"
	}
	_state_0:
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_ = g_slice_new0 (Block7Data);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->_ref_count_ = 1;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->self = g_object_ref (_data_->self);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->_async_data_ = _data_;
#line 395 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp0_ = _data_->changes;
#line 395 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp1_ = NULL;
#line 395 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp1_ = gee_multi_map_get_values (_data_->_tmp0_);
#line 395 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->added = _data_->_tmp1_;
#line 396 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp2_ = _data_->changes;
#line 396 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp3_ = NULL;
#line 396 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp3_ = gee_multi_map_get_keys (_data_->_tmp2_);
#line 396 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->removed = _data_->_tmp3_;
#line 398 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_get_current_time (&_data_->timeval);
#line 399 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_time_val_from_iso8601 ("1929-01-11T00:00:00Z", &_data_->timeval);
#line 400 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp4_ = _data_->timeval;
#line 400 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp5_ = g_date_time_new_from_timeval_utc (&_data_->_tmp4_);
#line 400 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->new_birthday = _data_->_tmp5_;
#line 401 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp6_ = folks_email_field_details_new ("cave@aperturescience.com", NULL);
#line 401 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->new_email_fd = _data_->_tmp6_;
#line 402 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp7_ = _data_->_data7_->new_email_fd;
#line 402 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp7_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_WORK);
#line 404 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp8_ = folks_phone_field_details_new ("+112233445566", NULL);
#line 404 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->new_phone_fd = _data_->_tmp8_;
#line 405 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp9_ = _data_->_data7_->new_phone_fd;
#line 405 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp9_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 407 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp10_ = folks_url_field_details_new ("aperturescience.com/cave", NULL);
#line 407 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->new_url_fd = _data_->_tmp10_;
#line 408 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp11_ = _data_->_data7_->new_url_fd;
#line 408 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp11_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_WORK);
#line 410 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp12_ = g_strdup ("Cave Johnson");
#line 410 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_->new_full_name = _data_->_tmp12_;
#line 3119 "individual-properties.c"
	{
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp13_ = _data_->added;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp14_ = NULL;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp14_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp13_);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_i_it = _data_->_tmp14_;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp15_ = _data_->_i_it;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp16_ = FALSE;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp16_ = gee_iterator_next (_data_->_tmp15_);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp16_) {
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 3141 "individual-properties.c"
			}
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp17_ = _data_->_i_it;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp18_ = NULL;
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp18_ = gee_iterator_get (_data_->_tmp17_);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->i = (FolksIndividual*) _data_->_tmp18_;
#line 414 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp19_ = _data_->i;
#line 414 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_data_->_tmp19_ != NULL);
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp21_ = _data_->i;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp22_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp21_);
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp23_ = _data_->_tmp22_;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_tmp23_ == NULL) {
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp20_ = TRUE;
#line 3165 "individual-properties.c"
			} else {
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp24_ = _data_->_data7_->new_birthday;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp25_ = _data_->i;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp26_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp25_);
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp27_ = _data_->_tmp26_;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp28_ = FALSE;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp28_ = g_date_time_equal (_data_->_tmp24_, _data_->_tmp27_);
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp20_ = !_data_->_tmp28_;
#line 3181 "individual-properties.c"
			}
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp29_ = _data_->_tmp20_;
#line 417 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_data_->_tmp29_);
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp30_ = _data_->i;
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp31_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _data_->_tmp30_);
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp32_ = _data_->_tmp31_;
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp33_ = _data_->_data7_->new_email_fd;
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp34_ = FALSE;
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp34_ = gee_collection_contains ((GeeCollection*) _data_->_tmp32_, _data_->_tmp33_);
#line 418 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (!_data_->_tmp34_);
#line 419 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp35_ = _data_->_data7_->new_full_name;
#line 419 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp36_ = _data_->i;
#line 419 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp37_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp36_);
#line 419 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp38_ = _data_->_tmp37_;
#line 419 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (g_strcmp0 (_data_->_tmp35_, _data_->_tmp38_) != 0);
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp39_ = _data_->i;
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp40_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _data_->_tmp39_);
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp41_ = _data_->_tmp40_;
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp42_ = _data_->_data7_->new_phone_fd;
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp43_ = FALSE;
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp43_ = gee_collection_contains ((GeeCollection*) _data_->_tmp41_, _data_->_tmp42_);
#line 420 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (!_data_->_tmp43_);
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp44_ = _data_->i;
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp45_ = folks_url_details_get_urls ((FolksUrlDetails*) _data_->_tmp44_);
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp46_ = _data_->_tmp45_;
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp47_ = _data_->_data7_->new_url_fd;
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp48_ = FALSE;
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp48_ = gee_collection_contains ((GeeCollection*) _data_->_tmp46_, _data_->_tmp47_);
#line 421 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (!_data_->_tmp48_);
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp49_ = _data_->i;
#line 423 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp49_, "notify::birthday", (GCallback) _____lambda11__g_object_notify, block7_data_ref (_data_->_data7_), (GClosureNotify) block7_data_unref, 0);
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp50_ = _data_->i;
#line 435 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp50_, "notify::email-addresses", (GCallback) _____lambda12__g_object_notify, block7_data_ref (_data_->_data7_), (GClosureNotify) block7_data_unref, 0);
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp51_ = _data_->i;
#line 446 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp51_, "notify::full-name", (GCallback) _____lambda13__g_object_notify, block7_data_ref (_data_->_data7_), (GClosureNotify) block7_data_unref, 0);
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp52_ = _data_->i;
#line 455 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp52_, "notify::phone-numbers", (GCallback) _____lambda14__g_object_notify, block7_data_ref (_data_->_data7_), (GClosureNotify) block7_data_unref, 0);
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp53_ = _data_->i;
#line 466 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp53_, "notify::urls", (GCallback) _____lambda15__g_object_notify, block7_data_ref (_data_->_data7_), (GClosureNotify) block7_data_unref, 0);
#line 479 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->persona = NULL;
#line 3261 "individual-properties.c"
			{
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp54_ = _data_->i;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp55_ = folks_individual_get_personas (_data_->_tmp54_);
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp56_ = _data_->_tmp55_;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp57_ = NULL;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp57_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp56_);
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_p_it = _data_->_tmp57_;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp58_ = _data_->_p_it;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp59_ = FALSE;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp59_ = gee_iterator_next (_data_->_tmp58_);
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (!_data_->_tmp59_) {
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
						break;
#line 3287 "individual-properties.c"
					}
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp60_ = _data_->_p_it;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp61_ = NULL;
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp61_ = gee_iterator_get (_data_->_tmp60_);
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->p = (FolksPersona*) _data_->_tmp61_;
#line 482 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp62_ = _data_->p;
#line 482 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp63_ = _g_object_ref0 (_data_->_tmp62_);
#line 482 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 482 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->persona = _data_->_tmp63_;
#line 483 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->p);
#line 483 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					break;
#line 3309 "individual-properties.c"
				}
#line 480 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_p_it);
#line 3313 "individual-properties.c"
			}
#line 485 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp64_ = _data_->persona;
#line 485 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (TPF_IS_PERSONA (_data_->_tmp64_));
#line 487 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp65_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GHashFunc) folks_abstract_field_details_hash, (GEqualFunc) folks_abstract_field_details_equal);
#line 487 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->emails = _data_->_tmp65_;
#line 490 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp66_ = _data_->emails;
#line 490 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp67_ = _data_->_data7_->new_email_fd;
#line 490 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp66_, _data_->_tmp67_);
#line 491 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp68_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GHashFunc) folks_abstract_field_details_hash, (GEqualFunc) folks_abstract_field_details_equal);
#line 491 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->phones = _data_->_tmp68_;
#line 494 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp69_ = _data_->phones;
#line 494 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp70_ = _data_->_data7_->new_phone_fd;
#line 494 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp69_, _data_->_tmp70_);
#line 495 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp71_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GHashFunc) folks_abstract_field_details_hash, (GEqualFunc) folks_abstract_field_details_equal);
#line 495 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->urls = _data_->_tmp71_;
#line 498 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp72_ = _data_->urls;
#line 498 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp73_ = _data_->_data7_->new_url_fd;
#line 498 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp72_, _data_->_tmp73_);
#line 506 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->uncaught_errors = 0;
#line 508 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp74_ = _data_->i;
#line 508 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp75_ = folks_individual_get_is_user (_data_->_tmp74_);
#line 508 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp76_ = _data_->_tmp75_;
#line 508 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp76_) {
#line 509 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp77_ = _data_->uncaught_errors;
#line 509 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp77_ + 1;
#line 3363 "individual-properties.c"
			}
			{
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp78_ = _data_->persona;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp79_ = _data_->_data7_->new_birthday;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 1;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_birthday_details_change_birthday ((FolksBirthdayDetails*) TPF_PERSONA (_data_->_tmp78_), _data_->_tmp79_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3376 "individual-properties.c"
				_state_1:
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_birthday_details_change_birthday_finish ((FolksBirthdayDetails*) TPF_PERSONA (_data_->_tmp78_), _data_->_res_, &_data_->_inner_error_);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3384 "individual-properties.c"
						goto __catch0_folks_property_error;
					}
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					block7_data_unref (_data_->_data7_);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data7_ = NULL;
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 512 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3413 "individual-properties.c"
				}
			}
			goto __finally0;
			__catch0_folks_property_error:
			{
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e_birthday = _data_->_inner_error_;
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 516 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp80_ = _data_->i;
#line 516 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp81_ = folks_individual_get_is_user (_data_->_tmp80_);
#line 516 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp82_ = _data_->_tmp81_;
#line 516 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp82_) {
#line 517 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp83_ = _data_->uncaught_errors;
#line 517 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp83_ - 1;
#line 3435 "individual-properties.c"
				}
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e_birthday);
#line 3439 "individual-properties.c"
			}
			__finally0:
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				block7_data_unref (_data_->_data7_);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data7_ = NULL;
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 510 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3470 "individual-properties.c"
			}
#line 520 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp84_ = _data_->i;
#line 520 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp85_ = folks_individual_get_is_user (_data_->_tmp84_);
#line 520 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp86_ = _data_->_tmp85_;
#line 520 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp86_) {
#line 521 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp87_ = _data_->uncaught_errors;
#line 521 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp87_ + 1;
#line 3484 "individual-properties.c"
			}
			{
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp88_ = _data_->persona;
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp89_ = _data_->emails;
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 2;
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_email_details_change_email_addresses ((FolksEmailDetails*) TPF_PERSONA (_data_->_tmp88_), (GeeSet*) _data_->_tmp89_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3497 "individual-properties.c"
				_state_2:
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_email_details_change_email_addresses_finish ((FolksEmailDetails*) TPF_PERSONA (_data_->_tmp88_), _data_->_res_, &_data_->_inner_error_);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3505 "individual-properties.c"
						goto __catch1_folks_property_error;
					}
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					block7_data_unref (_data_->_data7_);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data7_ = NULL;
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 524 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3534 "individual-properties.c"
				}
			}
			goto __finally1;
			__catch1_folks_property_error:
			{
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e0 = _data_->_inner_error_;
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 530 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp90_ = _data_->i;
#line 530 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp91_ = folks_individual_get_is_user (_data_->_tmp90_);
#line 530 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp92_ = _data_->_tmp91_;
#line 530 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp92_) {
#line 531 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp93_ = _data_->uncaught_errors;
#line 531 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp93_ - 1;
#line 3556 "individual-properties.c"
				}
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e0);
#line 3560 "individual-properties.c"
			}
			__finally1:
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				block7_data_unref (_data_->_data7_);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data7_ = NULL;
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 522 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3591 "individual-properties.c"
			}
#line 534 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp94_ = _data_->i;
#line 534 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp95_ = folks_individual_get_is_user (_data_->_tmp94_);
#line 534 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp96_ = _data_->_tmp95_;
#line 534 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp96_) {
#line 535 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp97_ = _data_->uncaught_errors;
#line 535 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp97_ + 1;
#line 3605 "individual-properties.c"
			}
			{
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp98_ = _data_->persona;
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp99_ = _data_->_data7_->new_full_name;
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 3;
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_name_details_change_full_name ((FolksNameDetails*) TPF_PERSONA (_data_->_tmp98_), _data_->_tmp99_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3618 "individual-properties.c"
				_state_3:
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_name_details_change_full_name_finish ((FolksNameDetails*) TPF_PERSONA (_data_->_tmp98_), _data_->_res_, &_data_->_inner_error_);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3626 "individual-properties.c"
						goto __catch2_folks_property_error;
					}
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					block7_data_unref (_data_->_data7_);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data7_ = NULL;
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 538 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3655 "individual-properties.c"
				}
			}
			goto __finally2;
			__catch2_folks_property_error:
			{
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e1 = _data_->_inner_error_;
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 542 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp100_ = _data_->i;
#line 542 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp101_ = folks_individual_get_is_user (_data_->_tmp100_);
#line 542 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp102_ = _data_->_tmp101_;
#line 542 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp102_) {
#line 543 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp103_ = _data_->uncaught_errors;
#line 543 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp103_ - 1;
#line 3677 "individual-properties.c"
				}
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e1);
#line 3681 "individual-properties.c"
			}
			__finally2:
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				block7_data_unref (_data_->_data7_);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data7_ = NULL;
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 536 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3712 "individual-properties.c"
			}
#line 546 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp104_ = _data_->i;
#line 546 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp105_ = folks_individual_get_is_user (_data_->_tmp104_);
#line 546 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp106_ = _data_->_tmp105_;
#line 546 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp106_) {
#line 547 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp107_ = _data_->uncaught_errors;
#line 547 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp107_ + 1;
#line 3726 "individual-properties.c"
			}
			{
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp108_ = _data_->persona;
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp109_ = _data_->phones;
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 4;
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_phone_details_change_phone_numbers ((FolksPhoneDetails*) TPF_PERSONA (_data_->_tmp108_), (GeeSet*) _data_->_tmp109_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3739 "individual-properties.c"
				_state_4:
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_phone_details_change_phone_numbers_finish ((FolksPhoneDetails*) TPF_PERSONA (_data_->_tmp108_), _data_->_res_, &_data_->_inner_error_);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3747 "individual-properties.c"
						goto __catch3_folks_property_error;
					}
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					block7_data_unref (_data_->_data7_);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data7_ = NULL;
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 550 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3776 "individual-properties.c"
				}
			}
			goto __finally3;
			__catch3_folks_property_error:
			{
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e2 = _data_->_inner_error_;
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 556 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp110_ = _data_->i;
#line 556 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp111_ = folks_individual_get_is_user (_data_->_tmp110_);
#line 556 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp112_ = _data_->_tmp111_;
#line 556 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp112_) {
#line 557 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp113_ = _data_->uncaught_errors;
#line 557 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp113_ - 1;
#line 3798 "individual-properties.c"
				}
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e2);
#line 3802 "individual-properties.c"
			}
			__finally3:
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				block7_data_unref (_data_->_data7_);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data7_ = NULL;
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 548 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3833 "individual-properties.c"
			}
#line 560 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp114_ = _data_->i;
#line 560 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp115_ = folks_individual_get_is_user (_data_->_tmp114_);
#line 560 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp116_ = _data_->_tmp115_;
#line 560 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp116_) {
#line 561 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp117_ = _data_->uncaught_errors;
#line 561 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp117_ + 1;
#line 3847 "individual-properties.c"
			}
			{
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp118_ = _data_->persona;
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp119_ = _data_->urls;
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 5;
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_url_details_change_urls ((FolksUrlDetails*) TPF_PERSONA (_data_->_tmp118_), (GeeSet*) _data_->_tmp119_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3860 "individual-properties.c"
				_state_5:
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				folks_url_details_change_urls_finish ((FolksUrlDetails*) TPF_PERSONA (_data_->_tmp118_), _data_->_res_, &_data_->_inner_error_);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3868 "individual-properties.c"
						goto __catch4_folks_property_error;
					}
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					block7_data_unref (_data_->_data7_);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data7_ = NULL;
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 564 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3897 "individual-properties.c"
				}
			}
			goto __finally4;
			__catch4_folks_property_error:
			{
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e3 = _data_->_inner_error_;
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 570 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp120_ = _data_->i;
#line 570 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp121_ = folks_individual_get_is_user (_data_->_tmp120_);
#line 570 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp122_ = _data_->_tmp121_;
#line 570 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp122_) {
#line 571 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp123_ = _data_->uncaught_errors;
#line 571 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp123_ - 1;
#line 3919 "individual-properties.c"
				}
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e3);
#line 3923 "individual-properties.c"
			}
			__finally4:
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				block7_data_unref (_data_->_data7_);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data7_ = NULL;
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 562 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3954 "individual-properties.c"
			}
#line 574 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp124_ = _data_->i;
#line 574 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp125_ = folks_individual_get_is_user (_data_->_tmp124_);
#line 574 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp126_ = _data_->_tmp125_;
#line 574 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp126_) {
#line 576 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp127_ = _data_->uncaught_errors;
#line 576 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				g_assert (_data_->_tmp127_ == 0);
#line 3968 "individual-properties.c"
			}
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->urls);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->phones);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->emails);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->persona);
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->i);
#line 3980 "individual-properties.c"
		}
#line 412 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data_->_i_it);
#line 3984 "individual-properties.c"
	}
#line 580 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp128_ = _data_->removed;
#line 580 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp129_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp128_);
#line 580 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp130_ = _data_->_tmp129_;
#line 580 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_assert (_data_->_tmp130_ == 1);
#line 3994 "individual-properties.c"
	{
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp131_ = _data_->removed;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp132_ = NULL;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp132_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp131_);
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_r_it = _data_->_tmp132_;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp133_ = _data_->_r_it;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp134_ = FALSE;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp134_ = gee_iterator_next (_data_->_tmp133_);
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp134_) {
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 4016 "individual-properties.c"
			}
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp135_ = _data_->_r_it;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp136_ = NULL;
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp136_ = gee_iterator_get (_data_->_tmp135_);
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->r = (FolksIndividual*) _data_->_tmp136_;
#line 584 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp137_ = _data_->r;
#line 584 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			g_assert (_data_->_tmp137_ == NULL);
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->r);
#line 4032 "individual-properties.c"
		}
#line 582 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data_->_r_it);
#line 4036 "individual-properties.c"
	}
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->removed);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->added);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	block7_data_unref (_data_->_data7_);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data7_ = NULL;
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	if (_data_->_state_ == 0) {
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4050 "individual-properties.c"
	} else {
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4054 "individual-properties.c"
	}
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_object_unref (_data_->_async_result);
#line 392 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return FALSE;
#line 4060 "individual-properties.c"
}


static void individual_properties_tests_class_init (IndividualPropertiesTestsClass * klass) {
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_parent_class = g_type_class_peek_parent (klass);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_type_class_add_private (klass, sizeof (IndividualPropertiesTestsPrivate));
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = individual_properties_tests_real_set_up;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = individual_properties_tests_real_tear_down;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = individual_properties_tests_finalize;
#line 4075 "individual-properties.c"
}


static void individual_properties_tests_instance_init (IndividualPropertiesTests * self) {
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self->priv = INDIVIDUAL_PROPERTIES_TESTS_GET_PRIVATE (self);
#line 31 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->_test_timeout = 3;
#line 4084 "individual-properties.c"
}


static void individual_properties_tests_finalize (GObject* obj) {
	IndividualPropertiesTests * self;
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	self = INDIVIDUAL_PROPERTIES_TESTS (obj);
#line 29 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->tp_backend);
#line 32 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 27 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	G_OBJECT_CLASS (individual_properties_tests_parent_class)->finalize (obj);
#line 4098 "individual-properties.c"
}


GType individual_properties_tests_get_type (void) {
	static volatile gsize individual_properties_tests_type_id__volatile = 0;
	if (g_once_init_enter (&individual_properties_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (IndividualPropertiesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) individual_properties_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (IndividualPropertiesTests), 0, (GInstanceInitFunc) individual_properties_tests_instance_init, NULL };
		GType individual_properties_tests_type_id;
		individual_properties_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "IndividualPropertiesTests", &g_define_type_info, 0);
		g_once_init_leave (&individual_properties_tests_type_id__volatile, individual_properties_tests_type_id);
	}
	return individual_properties_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	IndividualPropertiesTests* _tmp1_;
	IndividualPropertiesTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 591 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_test_init (&args_length1, &args, NULL);
#line 593 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_test_get_root ();
#line 593 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	root = _tmp0_;
#line 594 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = individual_properties_tests_new ();
#line 594 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = _tmp1_;
#line 594 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 594 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 594 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_tmp2_);
#line 596 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_test_run ();
#line 598 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	result = 0;
#line 598 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 4143 "individual-properties.c"
}


int main (int argc, char ** argv) {
#line 589 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	g_type_init ();
#line 589 "/opt/gnome2/source/folks/tests/telepathy/individual-properties.vala"
	return _vala_main (argv, argc);
#line 4152 "individual-properties.c"
}



